@@ -9,10 +9,8 @@ class Confirm(BaseConsoleRender):
     title_inline = True
 
     def get_header(self):
-        confirm = '(Y/n)' if self.question.default else '(y/N)'
-        return ('{msg} {c}'
-                .format(msg=self.question.message,
-                        c=confirm))
+        confirm = "(Y/n)" if self.question.default else "(y/N)"
+        return "{msg} {c}".format(msg=self.question.message, c=confirm)
 
     def process_input(self, pressed):
         if pressed == key.CTRL_C:
@@ -21,9 +19,9 @@ class Confirm(BaseConsoleRender):
         if pressed.lower() == key.ENTER:
             raise errors.EndOfInput(self.question.default)
 
-        if pressed in 'yY':
+        if pressed in "yY":
             print(pressed)
             raise errors.EndOfInput(True)
-        if pressed in 'nN':
+        if pressed in "nN":
             print(pressed)
             raise errors.EndOfInput(False)
