@@ -12,8 +12,7 @@ half_options = int((MAX_OPTIONS_DISPLAYED_AT_ONCE - 1) / 2)
 class BaseConsoleRender(object):
     title_inline = False
 
-    def __init__(self, question, theme=None, terminal=None, show_default=False,
-                 *args, **kwargs):
+    def __init__(self, question, theme=None, terminal=None, show_default=False, *args, **kwargs):
         super(BaseConsoleRender, self).__init__(*args, **kwargs)
         self.question = question
         self.terminal = terminal or Terminal()
@@ -25,17 +24,16 @@ class BaseConsoleRender(object):
         return self.question.message
 
     def get_current_value(self):
-        return ''
+        return ""
 
     def get_options(self):
         return []
 
     def process_input(self, pressed):
-        raise NotImplementedError('Abstract')
+        raise NotImplementedError("Abstract")
 
     def handle_validation_error(self, error):
         if error.reason:
             return error.reason
 
-        return '"{e}" is not a valid {q}.'.format(e=error.value,
-                                                  q=self.question.name)
+        return '"{e}" is not a valid {q}.'.format(e=error.value, q=self.question.name)
